
 { records for analytical operations }

 UNIT UnForRec ;

 INTERFACE

 Const
   MaxDimR  = 5000 ;
   MaxDimZ  = 3500 ;
   MaxDimC  = 1100 ;
   MaxPowM  =   50 ;
   MaxActV  =    3 ;
   MaxPosV  =    3 ;
   MaxArgC  =    5 ;

 Type
   TNumZon  = Array[2..4] of ShortInt ; { power for J_2, J_3, J_4 }
   TCanPow  = Array[1..MaxActV] of ShortInt ; { power for L , G , H }
   TPosPow  = Array[1..MaxPosV] of ShortInt ; { power for  p , e , sin(i) }
   TArgumC  = Array[1..MaxArgC] of ShortInt ; { coef. for u~,v,E,Om~,t }

 Type { only one positional and one angular parameter }
   TRecOne  = Record { simple record : am * p^np * \cos (na*A) }
                np  : ShortInt ; { power for parametr }
                na  : ShortInt ; { coefficients in angular argument }
                am  : Extended ; { numerical value for amplitude }
              End;
   TRecDim  = Array[1..MaxDimR] of TRecOne ;
   TDimPtr  = ^TRecDim ;

 Type { more complex record with any positional and angular parameters }
   TRecZon  = Record
                np  : TPosPow ; { power for  p , e , sin(i) }
                na  : Array[1..2] of ShortInt ; { coefficients for u~, v }
                am  : Extended ; { amplitude }
                bf  : Char ; { 'C' for cos, 'S' for sin , 'Z' for const }
              End;
   TZonDim  = Array[1..MaxDimZ] of TRecZon ;
   TZonPtr  = ^TZonDim ;

 Type { the same but with the canonical elements and array for zonharm }
   TRecCan  = Record
                nj  : TNumZon ; { power for J_2, J_3, J_4 }
                nc  : TCanPow ; { power for L , G , H }
                np  : TPosPow ; { power for  p , e , sin(i) }
                na  : TArgumC ; { coefficients for u~, v , E , Om~ , t }
                am  : Extended ; { amplitude }
                bf  : Char ; { 'C' for cos, 'S' for sin , 'Z' for const }
              End;
   TCanDim  = Array[1..MaxDimC] of TRecCan ;
   TCanPtr  = ^TCanDim ;

 Type { record to use Bessel function expansion }
   TRecZop  = Record
                np  : TPosPow ; { power for  p , e , i }
                na  : Array[1..2] of ShortInt ; { coefficients for M , g }
                am  : Extended ; { amplitude }
                bf  : Char ; { 'C' for cos, 'S' for sin , 'Z' for const }
              End;
   TZopDim  = Array[1..MaxDimZ] of TRecZop ;
   TZopPtr  = ^TZopDim ;

 Const
   zonullo  : TRecZon =
              ( np  : ( 0 , 0 , 0 ) ;
                na  : ( 0 , 0 ) ;
                am  : 0.0 ;
                bf  : 'C' ) ; { simple nullo record }

 Const
   canullo  : TRecCan =
              ( nj  : ( 0 , 0 , 0 ) ;
                nc  : ( 0 , 0 , 0 ) ;
                np  : ( 0 , 0 , 0 ) ;
                na  : ( 0 , 0 , 0 , 0 , 0 ) ;
                am  : 0.0 ;
                bf  : 'C' ) ; { simple nullo record }

 Const
   zopullo  : TRecZop =
              ( np  : ( 0 , 0 , 0 ) ;
                na  : ( 0 , 0 ) ;
                am  : 0.0 ;
                bf  : 'C' ) ; { simple nullo record for expansion case }

 Var
   DimRecA  : TDimPtr ;
   DimRecB  : TDimPtr ;
   DimRecC  : TDimPtr ;
   ZonRecA  : TZonPtr ;
   ZonRecB  : TZonPtr ;
   ZonRecC  : TZonPtr ;
   CanRecA  : TCanPtr ;
   CanRecB  : TCanPtr ;
   CanRecC  : TCanPtr ;
   ZopRecA  : TZopPtr ;
   ZopRecB  : TZopPtr ;
   ZopRecC  : TZopPtr ;
   NumRecA  : Word ;
   NumRecB  : Word ;
   NumRecC  : Word ;

 IMPLEMENTATION

 END.
